Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(544)

Unified Diff: runtime/vm/native_arguments.h

Issue 1156143003: Refactor Isolate -> Thread in NativeArguments and exception handler jump. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Fix comment; remove unused accessor. Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/isolate.h ('k') | runtime/vm/native_entry.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/native_arguments.h
diff --git a/runtime/vm/native_arguments.h b/runtime/vm/native_arguments.h
index 26fcb5cd21f2da80699fd84a611b26b7b60d4277..8f643887ecd9fac3e9531c617e44a91bbdf476cb 100644
--- a/runtime/vm/native_arguments.h
+++ b/runtime/vm/native_arguments.h
@@ -20,10 +20,10 @@ DECLARE_FLAG(bool, verify_on_transition);
// Forward declarations.
class BootstrapNatives;
-class Isolate;
class Object;
class RawObject;
class Simulator;
+class Thread;
#if defined(TESTING) || defined(DEBUG)
@@ -85,7 +85,7 @@ class Simulator;
// subclass of ValueObject.
class NativeArguments {
public:
- Isolate* isolate() const { return isolate_; }
+ Thread* thread() const { return thread_; }
int ArgCount() const { return ArgcBits::decode(argc_tag_); }
RawObject* ArgAt(int index) const {
@@ -127,8 +127,8 @@ class NativeArguments {
*retval_ = value.raw();
}
- static intptr_t isolate_offset() {
- return OFFSET_OF(NativeArguments, isolate_);
+ static intptr_t thread_offset() {
+ return OFFSET_OF(NativeArguments, thread_);
}
static intptr_t argc_tag_offset() {
return OFFSET_OF(NativeArguments, argc_tag_);
@@ -221,7 +221,7 @@ class NativeArguments {
return 0;
}
- Isolate* isolate_; // Current isolate pointer.
+ Thread* thread_; // Current thread pointer.
int argc_tag_; // Encodes argument count and invoked native call type.
RawObject*(*argv_)[]; // Pointer to an array of arguments to runtime call.
RawObject** retval_; // Pointer to the return value area.
« no previous file with comments | « runtime/vm/isolate.h ('k') | runtime/vm/native_entry.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698